/*
 *  Copyright (C) 2013-2014 Katharina Breininger
 *
 *   This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */


public class TestHelpingMethods {
	public static void main(String[] args) {
		boolean firstTest;
		try {
			firstTest = test_fillIntegerArray();
		} catch (Exception e) {
			System.err.println("Test failed: "+e.getMessage());
			return;
		}
		if(!firstTest) {
			System.err.println("Test failed due to unknown reason!");
			return;
		}
		System.out.println("Test 'HelpingMethods' successfull");
	}
	
	private static boolean test_fillIntegerArray() throws Exception {
		// First test: Fill array with 100 numbers from 0 to 99
		int length = 100;
		int[] result = Alae_Tracker.fillIntegerArray(length, 0, 1);
		
		if(result.length != length)
			throw new Exception("Wrong number of elements in array 1.");
		for(int i = 0; i < length; i++) {
			if(result[i] != i)
				throw new Exception("Wrong element in array at position "+i+": Expected: "+i+" - Found: "+result[i]+".");
		}
		
		// Second test: Fill array with 25 numbers with a difference of 5, beginning at 5 (5, 10, 15, ...)
		length = 25;
		result = Alae_Tracker.fillIntegerArray(length, 5, 5);
		if(result.length != length) {
			throw new Exception("Wrong number of elements in array 2.");
		}

		for(int i = 0; i < length; i++) {
			if(result[i] != 5+i*5) {
				int value = 5+i*5;
				throw new Exception("Wrong element in array at position "+i+": Expected: "+value+" - Found: "+result[i]+".");
			}
		}
		
		// Third test: Try to get an array with length < 0 - should return null
		int[] result3 = Alae_Tracker.fillIntegerArray(-1, 0, 1);
		if(result3 != null) {
			throw new Exception("Method call fillIntegerArray(...) with a negative length is supposed to return null!");
		}
		
		// Forth test: Start with a negative number and use a negative stepsize
		length = 10;
		result = Alae_Tracker.fillIntegerArray(length, 0, -1);
		if(result.length != length) {
			throw new Exception("Wrong number of elements in array 4.");
		}
		for(int i = 0; i < length; i++) {
			if(result[i] != i*-1) {
				int value = i*-1;
				throw new Exception("Wrong element in array at position "+i+": Expected: "+value+" - Found: "+result[i]+".");
			}
		}
		return true;
	}
	
}
